港特首梁振英就住宅违建事件道歉 - BBC中文网 - 两岸三地
Description: 香港行政长官梁振英在各方压力下到立法会接受质询，就其大宅的违章建筑问题道歉。
Keywords: 香港, 梁振英, 行政长官, 特首, 山顶, 违章, 违例, 违法, 非法, 建筑, 僭建, 立法会

## 浏览协助

- 直接前往内部导航
- 浏览协助

## bbc.co.uk navigation

- BBC链接

检索词:
BBC Chinese

- 简体版
- 繁體版

# 港特首梁振英就住宅违建事件道歉

更新时间 2012年12月10日, 格林尼治标准时间10:41

- Facebook
- Twitter
- Google+
- 人人
- 开心网
- 新浪微博
- qq空间
- 联合报书签
- myshare书签
- 百度搜藏
- 豆瓣
- 转寄朋友
- 打印文稿

梁振英同时遭到泛民主派和亲北京阵营议员质问。

香港行政长官梁振英在各方压力下就其大宅的违章建筑（僭建）问题到立法会接受质询，并向香港民众道歉。

梁振英此前承认早在去年参选行政长官之前就已知悉其住宅的违建问题，引发诚信危机。

梁振英在星期二（12月10日）的答问大会开始之际在其演说中道歉，但强调他在违章建筑问题上没有隐瞒的意图和动机。

不过泛民主派议员们普遍指责梁振英“撒谎”，要求他马上辞职下台。

一些亲北京阵营议员欢迎梁振英道歉，且认为应能获得香港民众接受，但这些议员也质问梁振英有否向执法部门施压。

梁振英强调承诺将在两周内解决其住宅的违建问题。

## “郑重道歉”

香港媒体于6月份曝光梁振英大宅的首批违建部分后，于3月的选举中被击败的民主党参选人何俊仁向法院提出选举呈请，至11月中旬被终审法院驳回。

梁振英的山顶大宅于6月份被揭发存有违章建筑。

梁振英说，其位于太平山山顶的住宅内的违建部分大都不是由他所建，此前没有马上公开交待和处理，是因为律师意见认为司法程序仍在进行，他不应评论。

梁振英在接受质询前的发言中说：“回顾事件，我虽然从无任何存心隐瞒的意图，但必须承认自己有处理疏忽及交代不清之处，为此我再次向市民郑重道歉。”

梁振英在选举中还击败了曾是自由党党员的前政务司司长唐英年。

在回答自由党议员的提问时，梁振英称，他从未说过其房产不存在违建问题。

现为间选议员的何俊仁说，梁振英至今仍不坦诚以对，让他“震惊”；亲北京政团工联会直选议员黄国健也批评梁振英抱着“不服输”的态度接受质询。

历时1.5小时的答问大会在进入中段之际，泛民主派人民力量的直选议员黄毓民、陈伟业和社会民主连线的梁国雄先后因播放录音、叫嚣，和向梁振英扔掷文件而被议长驱逐。

民主党此前计划在星期三（11日）对梁振英提出不信任动议。

点击 页首

- Facebook
- Twitter
- Google+
- 人人
- 开心网
- 新浪微博
- qq空间
- 联合报书签
- myshare书签
- 百度搜藏
- 豆瓣
- 转寄朋友
- 打印文稿

## 与内文相关的链接

### 相关内容

- 梁振英定下出席违建事件质询日期

  2012年12月6日

  ,

  香港

- 港屋宇署确认梁振英大宅更多违建

  2012年11月27日

  ,

  香港

- 香港观察：道德荏弱的梁振英班子

  2012年11月20日

  ,

  中国

- 香港廉署“已就梁振英违建立案”

  2012年6月27日

  ,

  香港

- 音频：刘锐绍评港人为何不信梁振英收听05:02

  2012年7月2日

  ,

  音频材料

- 梁振英僭建被指可能涉选举失实

  2012年6月22日

  ,

  香港

## 相关新闻话题

- 香港

### BBC以外链接

- 香港立法会
- 香港行政长官办公室

非本网站内容BBC概不负责

## 头条新闻

RSS

- 罗德曼就涉及裴埈皓的采访言论道歉 2014年1月9日
- 2013海外中国游客接近一亿 2014年1月9日
- 奥巴马拟限制美国国安局窃听外国元首 2014年1月9日
- 习近平出席政法会议再次强调维稳 2014年1月9日
- 中国国务院任命李刚升任澳门中联办主任 2014年1月9日

## 特别推荐

- 全球烟民接近10亿 中国占3亿

- 中国：风能源的“强劲”推广者

- 罗德曼为朝鲜领导人金正恩唱歌祝寿

- 英国《卫报》：网页在中国被封锁

- “中国电信业试松绑 习近平改革深水区试水”

- 民调：过半中国企业家称难同日企合作

- 分析：中国油气资源方向性预测
- 中国“摇滚教父”崔健或上今年春晚
- 人物：影视大亨邵逸夫的传奇一生
- 毛泽东诞辰120周年

## 音频视频

- 视频：3D打印巧克力现身电器展收看02:39

- 视频：中国举行公开销毁非法象牙活动收看01:17

- 视频：两分钟带您跑完上海新地铁收看01:21

- 视频：2013年全球大事回顾（下）收看03:30

- 视频：2013年全球大事回顾（中）收看03:36

- 视频：2013年全球大事回顾（上）收看03:16

- 音频：中国学者韩德强谈毛泽东收听13:03

- 视频：美国青年一百欧元赢得毕加索名画收看00:34

## 最多人阅读

﻿

1. 习近平出席政法会议再次强调维稳
2. 罗德曼就涉及裴埈皓的采访言论道歉
3. 中国将靖国神社之争诉诸联合国
4. “中国电信业试松绑 习近平改革深水区试水”
5. 去年中国CPI增2.6% 远低调控目标

## BBC英伦网精彩内容

- 中国富豪令英国游艇公司前景光明
- 中国绿地房产收购伦敦6亿英镑开发项目
- 观察：英国首相为何都不戴结婚戒指？

- 新闻主页
- 国际
- 两岸
- 英国
- 评论
- 互动
- 科技
- 财经
- 英超
- 娱乐
- 留学
- 学英语
- 多媒体
- 天气

## 服务专区

- 手机版
- 电邮新闻
- RSS服务
- 播客

## 相关网站

- BBC中文网合作伙伴
- BBC英伦网
- BBC其它语言网站
- BBC News

## BBC链接

- - 手机版
  - 使用条款
  - BBC中文网简介
- - Advertise with Us
  - 保密政策
  - 浏览协助
- - 与BBC联络

BBC © 2014 非本网站内容BBC概不负责

如欲取得最佳浏览效果，请使用最新的、使用串联样式表（CSS）的浏览器。虽然你可以使用目前的浏览器浏览网站，但是，你不能获得最佳视觉享受。请考虑使用最新版本的浏览器软件或在可能情况下让你的浏览器可以使用串联样式表。